@@ -2,6 +2,8 @@ import numbers
 
 import numpy as np
 
+__all__ = ['assert_aligned_axes_compatible']
+
 
 def _sanitize_aligned_axes(keys, data, aligned_axes):
     if aligned_axes is None:
@@ -109,7 +111,7 @@ def _sanitize_user_aligned_axes(data, aligned_axes):
 
 
 def _update_aligned_axes(drop_aligned_axes_indices, aligned_axes, first_key):
-    # Remove dropped axes from aligned_axes.  MUST BE A BETTER WAY TO DO THIS.
+    # Remove dropped axes from aligned_axes. MUST BE A BETTER WAY TO DO THIS.
     if len(drop_aligned_axes_indices) <= 0:
         new_aligned_axes = tuple(aligned_axes.values())
     elif len(drop_aligned_axes_indices) == len(aligned_axes[first_key]):
@@ -150,10 +152,16 @@ def assert_aligned_axes_compatible(data_dimensions1, data_dimensions2, data_axes
         The aligned axes of data cube 2.
 
     """
-    # Confirm same number of aligned axes.
-    if len(data_axes1) != len(data_axes2):
-        raise ValueError("Number of aligned axes must be equal: "
-                         f"{len(data_axes1)} != {len(data_axes2)}")
-    # Confirm dimension lengths of each aligned axis is the same.
-    if not all(data_dimensions1[np.array(data_axes1)] == data_dimensions2[np.array(data_axes2)]):
-        raise ValueError("All corresponding aligned axes between cubes must be of same length.")
+    # If one set of aligned axes is None and the other isn't, they are defined as not compatible.
+    if (data_axes1 is None and data_axes2 is not None) or (data_axes1 is not None and data_axes2 is None):
+        raise ValueError("Both collections must use aligned_axes or both axes must not use aligned_axes."
+                         f"Currently {data_axes1} != {data_axes2}")
+
+    if data_axes1 is not None and data_axes2 is not None:  # aligned_axes are being used for both collections
+        # Confirm same number of aligned axes.
+        if len(data_axes1) != len(data_axes2):
+            raise ValueError("Number of aligned axes must be equal: "
+                             f"{len(data_axes1)} != {len(data_axes2)}")
+        # Confirm dimension lengths of each aligned axis is the same.
+        if not all(data_dimensions1[np.array(data_axes1)] == data_dimensions2[np.array(data_axes2)]):
+            raise ValueError("All corresponding aligned axes between cubes must be of same length.")
